==> ejc-settlementmanage-impl-3.0.0-20220420.035439-5-sources.jar: com/ejianc/business/settlementmanage/vo/SubcontractCountersignedVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.settlementmanage.vo.SubcontractCountersignedDetilesVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 分包结算条件会签单-主表
 * 
 * @author generator
 * 
 */
public class SubcontractCountersignedVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Long subcontractedProjectId; // 分包工程ID
    private java.lang.String subcontractedProjectName; // 分包工程名称
    private java.lang.Long subcontractProjectManagerId; // 分包项目经理ID
    private java.lang.String subcontractProjectManagerName; // 分包项目经理名称
    private java.lang.String phone; // 联系电话
    private java.lang.String idCard; // 身份证号码
    private java.lang.String contractCode; // 合同编码
    private java.lang.String subcontractPricingMethod; // 分包计价方式
    private java.math.BigDecimal originalContractPrice; // 原合同价
    private java.math.BigDecimal projectSettlementPrice; // 分包商结算书送审总造价
    private java.math.BigDecimal projectSettlement; // 分包商工程结算书(式)
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date sendingDate; // 送签日期
    private java.lang.Long agentId; // 经办人id
    private java.lang.String agentName; // 经办人名称
    private java.lang.String remarks; // 备注
    private java.lang.Integer projectSettlementf; // 分包商工程结算书(份)
    private java.lang.Long agentDepartment; // 经办人部门
    private java.lang.Long madeId; // 分包人id
    private java.lang.String madeName; // 分包人名称
    private java.lang.String madeAddress; // 分包人单位地址
    private java.lang.String qualification; // 企业资质
    private java.lang.String postcode; // 邮政编码
    private java.lang.String content; // 联系人
    private java.lang.String subPhone; // 分包人联系电话
    private java.lang.String fax; // 联系传真
    private java.lang.String nature; // 企业性质
    private java.lang.String legal; // 法人代表
    private java.lang.String legalPhone; // 法人联系电话
    private java.lang.String createTimeShow; // 创建时间文本显示
    private java.lang.String billStateStr; // 单据状态Str
    private java.lang.String contractType;//合同类型
    private List<SubcontractCountersignedDetilesVO> subcontractCountersignedDetilesEntities = new ArrayList<>(); // 分包结算条件会签单-子表

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")

    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer

    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-outcontract")

    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer

    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 分包工程ID
     */
    public java.lang.Long getSubcontractedProjectId() {
        return subcontractedProjectId;
    }

    /**
     * 分包工程ID
     */
    public void setSubcontractedProjectId(java.lang.Long subcontractedProjectId) {
        this.subcontractedProjectId = subcontractedProjectId;
    }
    /**
     * 分包工程名称
     */
    public java.lang.String getSubcontractedProjectName() {
        return subcontractedProjectName;
    }

    /**
     * 分包工程名称
     */
    public void setSubcontractedProjectName(java.lang.String subcontractedProjectName) {
        this.subcontractedProjectName = subcontractedProjectName;
    }
    /**
     * 分包项目经理ID
     */
    @ReferSerialTransfer(referCode="idm-user")

    public java.lang.Long getSubcontractProjectManagerId() {
        return subcontractProjectManagerId;
    }

    /**
     * 分包项目经理ID
     */
    @ReferDeserialTransfer

    public void setSubcontractProjectManagerId(java.lang.Long subcontractProjectManagerId) {
        this.subcontractProjectManagerId = subcontractProjectManagerId;
    }
    /**
     * 分包项目经理名称
     */
    public java.lang.String getSubcontractProjectManagerName() {
        return subcontractProjectManagerName;
    }

    /**
     * 分包项目经理名称
     */
    public void setSubcontractProjectManagerName(java.lang.String subcontractProjectManagerName) {
        this.subcontractProjectManagerName = subcontractProjectManagerName;
    }
    /**
     * 联系电话
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系电话
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }
    /**
     * 身份证号码
     */
    public java.lang.String getIdCard() {
        return idCard;
    }

    /**
     * 身份证号码
     */
    public void setIdCard(java.lang.String idCard) {
        this.idCard = idCard;
    }
    /**
     * 合同编码
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编码
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 分包计价方式
     */
    public java.lang.String getSubcontractPricingMethod() {
        return subcontractPricingMethod;
    }

    /**
     * 分包计价方式
     */
    public void setSubcontractPricingMethod(java.lang.String subcontractPricingMethod) {
        this.subcontractPricingMethod = subcontractPricingMethod;
    }
    /**
     * 原合同价
     */
    public java.math.BigDecimal getOriginalContractPrice() {
        return originalContractPrice;
    }

    /**
     * 原合同价
     */
    public void setOriginalContractPrice(java.math.BigDecimal originalContractPrice) {
        this.originalContractPrice = originalContractPrice;
    }
    /**
     * 分包商结算书送审总造价
     */
    public java.math.BigDecimal getProjectSettlementPrice() {
        return projectSettlementPrice;
    }

    /**
     * 分包商结算书送审总造价
     */
    public void setProjectSettlementPrice(java.math.BigDecimal projectSettlementPrice) {
        this.projectSettlementPrice = projectSettlementPrice;
    }
    /**
     * 分包商工程结算书(式)
     */
    public java.math.BigDecimal getProjectSettlement() {
        return projectSettlement;
    }

    /**
     * 分包商工程结算书(式)
     */
    public void setProjectSettlement(java.math.BigDecimal projectSettlement) {
        this.projectSettlement = projectSettlement;
    }
    /**
     * 送签日期
     */
    public java.util.Date getSendingDate() {
        return sendingDate;
    }

    /**
     * 送签日期
     */
    public void setSendingDate(java.util.Date sendingDate) {
        this.sendingDate = sendingDate;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")

    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer

    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }

    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 分包商工程结算书(份)
     */
    public java.lang.Integer getProjectSettlementf() {
        return projectSettlementf;
    }

    /**
     * 分包商工程结算书(份)
     */
    public void setProjectSettlementf(java.lang.Integer projectSettlementf) {
        this.projectSettlementf = projectSettlementf;
    }
    /**
     * 经办人部门
     */
    @ReferSerialTransfer(referCode="idm-dept")

    public java.lang.Long getAgentDepartment() {
        return agentDepartment;
    }

    /**
     * 经办人部门
     */
    @ReferDeserialTransfer
    public void setAgentDepartment(java.lang.Long agentDepartment) {
        this.agentDepartment = agentDepartment;
    }
    /**
     * 分包人id
     */
    @ReferSerialTransfer(referCode="support-supplier")
    public java.lang.Long getMadeId() {
        return madeId;
    }

    /**
     * 分包人id
     */
    @ReferDeserialTransfer
    public void setMadeId(java.lang.Long madeId) {
        this.madeId = madeId;
    }
    /**
     * 分包人名称
     */
    public java.lang.String getMadeName() {
        return madeName;
    }

    /**
     * 分包人名称
     */
    public void setMadeName(java.lang.String madeName) {
        this.madeName = madeName;
    }
    /**
     * 分包人单位地址
     */
    public java.lang.String getMadeAddress() {
        return madeAddress;
    }

    /**
     * 分包人单位地址
     */
    public void setMadeAddress(java.lang.String madeAddress) {
        this.madeAddress = madeAddress;
    }
    /**
     * 企业资质
     */
    public java.lang.String getQualification() {
        return qualification;
    }

    /**
     * 企业资质
     */
    public void setQualification(java.lang.String qualification) {
        this.qualification = qualification;
    }
    /**
     * 邮政编码
     */
    public java.lang.String getPostcode() {
        return postcode;
    }

    /**
     * 邮政编码
     */
    public void setPostcode(java.lang.String postcode) {
        this.postcode = postcode;
    }
    /**
     * 联系人
     */
    public java.lang.String getContent() {
        return content;
    }

    /**
     * 联系人
     */
    public void setContent(java.lang.String content) {
        this.content = content;
    }
    /**
     * 分包人联系电话
     */
    public java.lang.String getSubPhone() {
        return subPhone;
    }

    /**
     * 分包人联系电话
     */
    public void setSubPhone(java.lang.String subPhone) {
        this.subPhone = subPhone;
    }
    /**
     * 联系传真
     */
    public java.lang.String getFax() {
        return fax;
    }

    /**
     * 联系传真
     */
    public void setFax(java.lang.String fax) {
        this.fax = fax;
    }
    /**
     * 企业性质
     */
    public java.lang.String getNature() {
        return nature;
    }

    /**
     * 企业性质
     */
    public void setNature(java.lang.String nature) {
        this.nature = nature;
    }
    /**
     * 法人代表
     */
    public java.lang.String getLegal() {
        return legal;
    }

    /**
     * 法人代表
     */
    public void setLegal(java.lang.String legal) {
        this.legal = legal;
    }
    /**
     * 法人联系电话
     */
    public java.lang.String getLegalPhone() {
        return legalPhone;
    }

    /**
     * 法人联系电话
     */
    public void setLegalPhone(java.lang.String legalPhone) {
        this.legalPhone = legalPhone;
    }

    public List<SubcontractCountersignedDetilesVO> getSubcontractCountersignedDetilesEntities() {
        return subcontractCountersignedDetilesEntities;
    }

    public void setSubcontractCountersignedDetilesEntities(List<SubcontractCountersignedDetilesVO> subcontractCountersignedDetilesEntities) {
        this.subcontractCountersignedDetilesEntities = subcontractCountersignedDetilesEntities;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20220425.073851-9-sources.jar: com/ejianc/business/settlementmanage/vo/SubcontractCountersignedVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.settlementmanage.vo.SubcontractCountersignedDetilesVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 分包结算条件会签单-主表
 * 
 * @author generator
 * 
 */
public class SubcontractCountersignedVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Long subcontractedProjectId; // 分包工程ID
    private java.lang.String subcontractedProjectName; // 分包工程名称
    private java.lang.Long subcontractProjectManagerId; // 分包项目经理ID
    private java.lang.String subcontractProjectManagerName; // 分包项目经理名称
    private java.lang.String phone; // 联系电话
    private java.lang.String idCard; // 身份证号码
    private java.lang.String contractCode; // 合同编码
    private java.lang.String subcontractPricingMethod; // 分包计价方式
    private java.math.BigDecimal originalContractPrice; // 原合同价
    private java.math.BigDecimal projectSettlementPrice; // 分包商结算书送审总造价
    private java.math.BigDecimal projectSettlement; // 分包商工程结算书(式)
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date sendingDate; // 送签日期
    private java.lang.Long agentId; // 经办人id
    private java.lang.String agentName; // 经办人名称
    private java.lang.String remarks; // 备注
    private java.lang.Integer projectSettlementf; // 分包商工程结算书(份)
    private java.lang.Long agentDepartment; // 经办人部门
    private java.lang.Long madeId; // 分包人id
    private java.lang.String madeName; // 分包人名称
    private java.lang.String madeAddress; // 分包人单位地址
    private java.lang.String qualification; // 企业资质
    private java.lang.String postcode; // 邮政编码
    private java.lang.String content; // 联系人
    private java.lang.String subPhone; // 分包人联系电话
    private java.lang.String fax; // 联系传真
    private java.lang.String nature; // 企业性质
    private java.lang.String legal; // 法人代表
    private java.lang.String legalPhone; // 法人联系电话
    private java.lang.String createTimeShow; // 创建时间文本显示
    private java.lang.String billStateStr; // 单据状态Str
    private java.lang.String contractType;//合同类型
    private List<SubcontractCountersignedDetilesVO> subcontractCountersignedDetilesEntities = new ArrayList<>(); // 分包结算条件会签单-子表

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")

    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer

    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-outcontract")

    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer

    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 分包工程ID
     */
    public java.lang.Long getSubcontractedProjectId() {
        return subcontractedProjectId;
    }

    /**
     * 分包工程ID
     */
    public void setSubcontractedProjectId(java.lang.Long subcontractedProjectId) {
        this.subcontractedProjectId = subcontractedProjectId;
    }
    /**
     * 分包工程名称
     */
    public java.lang.String getSubcontractedProjectName() {
        return subcontractedProjectName;
    }

    /**
     * 分包工程名称
     */
    public void setSubcontractedProjectName(java.lang.String subcontractedProjectName) {
        this.subcontractedProjectName = subcontractedProjectName;
    }
    /**
     * 分包项目经理ID
     */
    @ReferSerialTransfer(referCode="idm-user")

    public java.lang.Long getSubcontractProjectManagerId() {
        return subcontractProjectManagerId;
    }

    /**
     * 分包项目经理ID
     */
    @ReferDeserialTransfer

    public void setSubcontractProjectManagerId(java.lang.Long subcontractProjectManagerId) {
        this.subcontractProjectManagerId = subcontractProjectManagerId;
    }
    /**
     * 分包项目经理名称
     */
    public java.lang.String getSubcontractProjectManagerName() {
        return subcontractProjectManagerName;
    }

    /**
     * 分包项目经理名称
     */
    public void setSubcontractProjectManagerName(java.lang.String subcontractProjectManagerName) {
        this.subcontractProjectManagerName = subcontractProjectManagerName;
    }
    /**
     * 联系电话
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系电话
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }
    /**
     * 身份证号码
     */
    public java.lang.String getIdCard() {
        return idCard;
    }

    /**
     * 身份证号码
     */
    public void setIdCard(java.lang.String idCard) {
        this.idCard = idCard;
    }
    /**
     * 合同编码
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编码
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 分包计价方式
     */
    public java.lang.String getSubcontractPricingMethod() {
        return subcontractPricingMethod;
    }

    /**
     * 分包计价方式
     */
    public void setSubcontractPricingMethod(java.lang.String subcontractPricingMethod) {
        this.subcontractPricingMethod = subcontractPricingMethod;
    }
    /**
     * 原合同价
     */
    public java.math.BigDecimal getOriginalContractPrice() {
        return originalContractPrice;
    }

    /**
     * 原合同价
     */
    public void setOriginalContractPrice(java.math.BigDecimal originalContractPrice) {
        this.originalContractPrice = originalContractPrice;
    }
    /**
     * 分包商结算书送审总造价
     */
    public java.math.BigDecimal getProjectSettlementPrice() {
        return projectSettlementPrice;
    }

    /**
     * 分包商结算书送审总造价
     */
    public void setProjectSettlementPrice(java.math.BigDecimal projectSettlementPrice) {
        this.projectSettlementPrice = projectSettlementPrice;
    }
    /**
     * 分包商工程结算书(式)
     */
    public java.math.BigDecimal getProjectSettlement() {
        return projectSettlement;
    }

    /**
     * 分包商工程结算书(式)
     */
    public void setProjectSettlement(java.math.BigDecimal projectSettlement) {
        this.projectSettlement = projectSettlement;
    }
    /**
     * 送签日期
     */
    public java.util.Date getSendingDate() {
        return sendingDate;
    }

    /**
     * 送签日期
     */
    public void setSendingDate(java.util.Date sendingDate) {
        this.sendingDate = sendingDate;
    }
    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")

    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer

    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }

    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 分包商工程结算书(份)
     */
    public java.lang.Integer getProjectSettlementf() {
        return projectSettlementf;
    }

    /**
     * 分包商工程结算书(份)
     */
    public void setProjectSettlementf(java.lang.Integer projectSettlementf) {
        this.projectSettlementf = projectSettlementf;
    }
    /**
     * 经办人部门
     */
    @ReferSerialTransfer(referCode="idm-dept")

    public java.lang.Long getAgentDepartment() {
        return agentDepartment;
    }

    /**
     * 经办人部门
     */
    @ReferDeserialTransfer
    public void setAgentDepartment(java.lang.Long agentDepartment) {
        this.agentDepartment = agentDepartment;
    }
    /**
     * 分包人id
     */
    @ReferSerialTransfer(referCode="support-supplier")
    public java.lang.Long getMadeId() {
        return madeId;
    }

    /**
     * 分包人id
     */
    @ReferDeserialTransfer
    public void setMadeId(java.lang.Long madeId) {
        this.madeId = madeId;
    }
    /**
     * 分包人名称
     */
    public java.lang.String getMadeName() {
        return madeName;
    }

    /**
     * 分包人名称
     */
    public void setMadeName(java.lang.String madeName) {
        this.madeName = madeName;
    }
    /**
     * 分包人单位地址
     */
    public java.lang.String getMadeAddress() {
        return madeAddress;
    }

    /**
     * 分包人单位地址
     */
    public void setMadeAddress(java.lang.String madeAddress) {
        this.madeAddress = madeAddress;
    }
    /**
     * 企业资质
     */
    public java.lang.String getQualification() {
        return qualification;
    }

    /**
     * 企业资质
     */
    public void setQualification(java.lang.String qualification) {
        this.qualification = qualification;
    }
    /**
     * 邮政编码
     */
    public java.lang.String getPostcode() {
        return postcode;
    }

    /**
     * 邮政编码
     */
    public void setPostcode(java.lang.String postcode) {
        this.postcode = postcode;
    }
    /**
     * 联系人
     */
    public java.lang.String getContent() {
        return content;
    }

    /**
     * 联系人
     */
    public void setContent(java.lang.String content) {
        this.content = content;
    }
    /**
     * 分包人联系电话
     */
    public java.lang.String getSubPhone() {
        return subPhone;
    }

    /**
     * 分包人联系电话
     */
    public void setSubPhone(java.lang.String subPhone) {
        this.subPhone = subPhone;
    }
    /**
     * 联系传真
     */
    public java.lang.String getFax() {
        return fax;
    }

    /**
     * 联系传真
     */
    public void setFax(java.lang.String fax) {
        this.fax = fax;
    }
    /**
     * 企业性质
     */
    public java.lang.String getNature() {
        return nature;
    }

    /**
     * 企业性质
     */
    public void setNature(java.lang.String nature) {
        this.nature = nature;
    }
    /**
     * 法人代表
     */
    public java.lang.String getLegal() {
        return legal;
    }

    /**
     * 法人代表
     */
    public void setLegal(java.lang.String legal) {
        this.legal = legal;
    }
    /**
     * 法人联系电话
     */
    public java.lang.String getLegalPhone() {
        return legalPhone;
    }

    /**
     * 法人联系电话
     */
    public void setLegalPhone(java.lang.String legalPhone) {
        this.legalPhone = legalPhone;
    }

    public List<SubcontractCountersignedDetilesVO> getSubcontractCountersignedDetilesEntities() {
        return subcontractCountersignedDetilesEntities;
    }

    public void setSubcontractCountersignedDetilesEntities(List<SubcontractCountersignedDetilesVO> subcontractCountersignedDetilesEntities) {
        this.subcontractCountersignedDetilesEntities = subcontractCountersignedDetilesEntities;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }
}
